/*
 * Copyright 2016 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.forms.model;

import java.util.List;

/**
 * Defines the FormModel that the form is going to handle
 */
public interface FormModel {

    /**
     * Returns the name of the FormModel
     */
    String getName();

    /**
     * Returns a {@link List} containing all the model {@link ModelProperty}
     */
    List<ModelProperty> getProperties();

    /**
     * Returns {@link ModelProperty} identified by the name parameter
     */
    ModelProperty getProperty(String name);
}
